/*
 *  GRUB  --  GRand Unified Bootloader
 *  Copyright (C) 2003,2005,2006,2007,2009  Free Software Foundation, Inc.
 *
 *  GRUB is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  GRUB is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with GRUB.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <grub/dl.h>
#include <grub/err.h>
#include <grub/mm.h>
#include <grub/command.h>
#include <grub/env.h>

GRUB_MOD_LICENSE ("GPLv3+");

static grub_err_t
grub_cmd_chpart (grub_command_t cmd __attribute__ ((unused)),
					   int argc,
					   char *args[])
{
	const char *var;
	char *device, *varname, *partname;
	char *p;
	grub_size_t len;

	if (argc != 2) {
		return grub_error (GRUB_ERR_BAD_ARGUMENT, N_("two arguments expected"));
	}
	varname = args[0];
	partname = args[1];

	var = grub_env_get (varname);
	if (! var) {
		return grub_error (GRUB_ERR_BAD_ARGUMENT, N_("%s is not set"), varname);
	}
	device = grub_strdup(var);
	p = grub_strchr(device, ',');
	if (p) {
		*p = 0;
	}

	len = grub_strlen (device) + grub_strlen (partname) + 2;
	p = (char *) grub_malloc (len);
	if (! p) {
		grub_free (device);
		return grub_error (GRUB_ERR_OUT_OF_MEMORY, N_("malloc error"));
	}
	grub_snprintf (p, len, "%s,%s", device, partname);
	grub_env_set (varname, p);

	grub_free (device);
	grub_free (p);

	return 0;
}

static grub_command_t cmd_chpart;

GRUB_MOD_INIT(chpart)
{
  cmd_chpart =
    grub_register_command ("chpart", grub_cmd_chpart,
			   N_("VARNAME STRING"), N_("change partition."));
}

GRUB_MOD_FINI(chpart)
{
  grub_unregister_command (cmd_chpart);
}

/* end of chpart.c */
